EngineInvariant

Enum EngineInvariant 

#[non_exhaustive]
pub enum EngineInvariant {
Show 15 variants I1 = 1, I2 = 2, I3 = 3, I4 = 4, I5 = 5, I6 = 6, I7 = 7, I8 = 8, I9 = 9, I10 = 10, I11 = 11, I12 = 12, I13 = 13, I14 = 14, I15 = 15,
}
Stable engine invariant identifier in the frozen data contract.

The numeric value matches the I{N} naming in the vyre specification. These numbers are permanent: new invariants add new variants, while existing variants never change meaning. Example: EngineInvariant::I4 identifies the IR wire-format round-trip invariant.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


I1 = 1

I1 Determinism.



I2 = 2

I2 Composition commutativity with lowering.



I3 = 3

I3 Backend equivalence.



I4 = 4

I4 IR wire-format round-trip.



I5 = 5

I5 Validation soundness.



I6 = 6

I6 Validation completeness, partial.



I7 = 7

I7 Law monotonicity under composition.



I8 = 8

I8 Reference agreement.



I9 = 9

I9 Law falsifiability.



I10 = 10

I10 Bounded allocation.



I11 = 11

I11 No panic.



I12 = 12

I12 No undefined behaviour.



I13 = 13

I13 Userspace stability.



I14 = 14

I14 Non-exhaustive discipline.



I15 = 15

I15 Certificate stability.

Implementations

Source

impl EngineInvariant

pub const fn ordinal(&self) -> u8

Stable one-based invariant number.

pub fn iter() -> impl Iterator<Item = Self>

Iterate over every known invariant id in declaration order.